==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delat som länk",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
    "You can upload into this folder" : "Du kan ladda upp i denna map",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
    "Invalid server URL" : "Ogiltig server URL",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum satt",
    "Shared by" : "Delad av",
    "Sharing" : "Delning",
    "File shares" : "Fildelningar",
    "Downloaded via public link" : "Nedladdad via offentlig länk",
    "Downloaded by %1$s" : "Nedladdad av %1$s",
    "Downloaded by {email}" : "Nedladdad av {email}",
    "%1$s downloaded via public link" : "%1$s nedladdad via offentlig länk",
    "{file} downloaded via public link" : "{file} nedladdad via offentlig länk",
    "%1$s downloaded %2$s" : "%1$s laddade ned %2$s",
    "{email} downloaded {file}" : "{email} laddade ned {file}",
    "Shared with group %1$s" : "Delad med grupp %1$s",
    "Shared with group {group}" : "Delad med grupp {group}",
    "Removed share for group %1$s" : "Tog bort delning för grupp %1$s",
    "Removed share for group {group}" : "Tog bort delning för grupp {group}",
    "%2$s shared with group %1$s" : "%2$s delad med grupp %1$s",
    "{actor} shared with group {group}" : "{actor} delade med gruppen {group}",
    "%2$s removed share for group %1$s" : "%2$s tog bort delningen för gruppen %1$s",
    "{actor} removed share for group {group}" : "{actor} tog bort delningen för gruppen {group}",
    "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
    "You shared {file} with group {group}" : "Du delade {file} med gruppen {group}",
    "You removed group %2$s from %1$s" : "Du tog bort gruppen %2$s från %1$s",
    "You removed group {group} from {file}" : "Du tog bort gruppen {group} från {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s delade %1$s med gruppen %2$s",
    "{actor} shared {file} with group {group}" : "{actor} delade {file} med gruppen {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s tog bort gruppen %2$s från %1$s",
    "{actor} removed group {group} from {file}" : "{actor} tog bort gruppen {group} från {file}",
    "Shared as public link" : "Delades offentligt",
    "Removed public link" : "Tog bort offentlig länk",
    "%1$s shared as public link" : "%1$s delade offentligt",
    "{actor} shared as public link" : "{actor} delade offentligt",
    "%1$s removed public link" : "%1$s tog bort offentlig länk",
    "{actor} removed public link" : "{actor} tog bort offentlig länk",
    "You shared %1$s as public link" : "Du delade %1$s offentligt",
    "You shared {file} as public link" : "Du delade {file} offentligt",
    "You removed public link for %1$s" : "Du tog bort den offentliga länken för %1$s",
    "You removed public link for {file}" : "Du tog bort den offentliga länken för {file}",
    "%2$s shared %1$s as public link" : "%2$s delade %1$s offentligt",
    "{actor} shared {file} as public link" : "{actor} delade {file} offentligt",
    "%2$s removed public link for %1$s" : "%2$s tog bort den offentliga länken för %1$s",
    "{actor} removed public link for {file}" : "{actor} tog bort den offentliga länken för {file}",
    "%1$s accepted the remote share" : "%1$s accepterade extern delning",
    "{user} accepted the remote share" : "{user} accepterade extern delning",
    "%1$s declined the remote share" : "%1$s nekade extern delning",
    "{user} declined the remote share" : "{user} nekade extern delning",
    "You received a new remote share %1$s from %2$s" : "Du har fått en ny extern delning %1$s från %2$s",
    "You received a new remote share {file} from {user}" : "Du har fått en ny extern delning {file} från {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s accepterade extern delning av %1$s",
    "{user} accepted the remote share of {file}" : "{user} accepterade extern delning av {file}",
    "%2$s declined the remote share of %1$s" : "%2$s nekade extern delning av %1$s",
    "{user} declined the remote share of {file}" : "{user} nekade extern delning av {file}",
    "%2$s unshared %1$s from you" : "%2$s slutade dela %1$s med dig",
    "{user} unshared {file} from you" : "{user} slutade dela {file} med dig",
    "Shared with %1$s" : "Delade med %1$s",
    "Shared with {user}" : "Delade med {user}",
    "Removed share for %1$s" : "Tog bort delningen för %1$s",
    "Removed share for {user}" : "Tog bort delningen för {user}",
    "%2$s shared with %1$s" : "%2$s delade med %1$s",
    "{actor} shared with {user}" : "{actor} delade med {user}",
    "%2$s removed share for %1$s" : "%2$s tog bort delningen för %1$s",
    "{actor} removed share for {user}" : "{actor} tog bort delningen för {user}",
    "Shared by %1$s" : "Delad av %1$s",
    "Shared by {actor}" : "Delad av {actor}",
    "%1$s removed share" : "%1$s tog bort delning",
    "{actor} removed share" : "{actor} tog bort delning",
    "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
    "You shared {file} with {user}" : "Du delade {file} med {user}",
    "You removed %2$s from %1$s" : "Du tog bort %2$s från %1$s",
    "You removed {user} from {file}" : "Du tog bort {user} från {file}",
    "%3$s shared %1$s with %2$s" : "%3$s delade %1$s med %2$s",
    "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
    "%3$s removed %2$s from %1$s" : "%3$s tog bort %2$s från %1$s",
    "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
    "{actor} shared {file} with you" : "{actor} delade {file} med dig",
    "%2$s removed you from %1$s" : "%2$s tog bort dig från %1$s",
    "{actor} removed you from {file}" : "{actor} tog bort dig från {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via mejl eller offentlig länk har blivit <strong>nedladdad</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "Wrong share ID, share doesn't exist" : "Fel delnings-ID, delningen finns inte",
    "could not delete share" : "kunde inte ta bort delningen",
    "Could not delete share" : "Kunde inte ta bort delningen",
    "Please specify a file or folder path" : "Ange sökväg till filen eller mappen",
    "Wrong path, file/folder doesn't exist" : "Fel sökväg, fil/mapp finns inte",
    "Could not create share" : "Kunde inte skapa delning",
    "invalid permissions" : "ogiltiga behörigheter",
    "Please specify a valid user" : "Ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är avstängt",
    "Please specify a valid group" : "Ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Offentlig delningslänk är avstängt",
    "Public upload disabled by the administrator" : "Offentlig uppladdning är avstängt",
    "Public upload is only possible for publicly shared folders" : "Offentlig uppladdning fungerar endast i offentligt delade mappar",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delningen av %s misslyckades. Ej tillåtet med delning av %s",
    "Unknown share type" : "Ogiltig delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökvägen",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Can't change permissions for public share links" : "Det går inte att ändra behörigheterna för offentliga länkar",
    "Cannot increase permissions" : "Kan inte utöka behörigheter",
    "%s is publicly shared" : "%s är offentligt delad",
    "Share API is disabled" : "Delning av API är inaktiverad",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Add to your Nextcloud" : "Lägg till i molnet",
    "Download" : "Ladda ned",
    "Download %s" : "Ladda ned %s",
    "Direct link" : "Direktlänk",
    "Upload files to %s" : "Ladda upp filer till %s",
    "Select or drop files" : "Välj eller dra filer hit",
    "Uploading files…" : "Laddar upp filer...",
    "Uploaded files:" : "Uppladdade filer:",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentligt delad fil eller mapp blev <strong>nedladdad</strong>",
    "You received a new remote share %2$s from %1$s" : "Du har mottagit en ny extern delning %2$s från %1$s",
    "You received a new remote share from %s" : "Du har mottagit en ny extern delning från %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterade extern delning %2$s",
    "%1$s declined remote share %2$s" : "%1$s nekade extern delning av %2$s",
    "%1$s unshared %2$s from you" : "%1$s tog bort delningen %2$s från dig",
    "Public shared folder %1$s was downloaded" : "Offentligt delad mapp %1$s blev nedladdad",
    "Public shared file %1$s was downloaded" : "Offentligt delad fil %1$s blev nedladdad",
    "%2$s shared %1$s with %3$s" : "%2$s delade %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du tog bort delning av %2$s för %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s tog bort delningen av %3$s för %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delade %1$s med gruppen %3$s",
    "You removed the share of group %2$s for %1$s" : "Du tog bort delningen av gruppen %2$s för %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s tog bort delningen av grupp %3$s för %1$s",
    "%2$s shared %1$s via link" : "%2$s delade %1$s via länk",
    "You shared %1$s via link" : "Du delade %1$s via länk",
    "You removed the public link for %1$s" : "Du tog bort den offentliga länken för %1$s",
    "%2$s removed the public link for %1$s" : "%2$s tog bort den offentliga länken för %1$s",
    "Your public link for %1$s expired" : "Din offentliga länk för %1$s har löpt ut",
    "The public link of %2$s for %1$s expired" : "Den offentliga länken för %2$s av %1$s har löpt ut",
    "%2$s removed the share for %1$s" : "%2$s tog bort delningen av %1$s",
    "Shared with %2$s" : "Delad med %2$s",
    "Shared with %3$s by %2$s" : "Delad med %3$s av %2$s",
    "Removed share for %2$s" : "Tog bort delningen för %2$s",
    "%2$s removed share for %3$s" : "%2$s tog bort delningen för %3$s",
    "Shared with group %2$s" : "Delning med grupp %2$s",
    "Shared with group %3$s by %2$s" : "Delade med grupp %3$s av %2$s",
    "Removed share of group %2$s" : "Tog bort delning av grupp %2$s",
    "%2$s removed share of group %3$s" : "%2$s tog bort delningen av grupp %3$s",
    "Shared via link by %2$s" : "Delad via länk av %2$s",
    "Shared via public link" : "Delad via offentlig länk",
    "%2$s removed public link" : "%2$s tog bort offentlig länk",
    "Public link expired" : "Tidsgräns för offentlig länk har löpt ut",
    "Public link of %2$s expired" : "Tidsgräns för offentlig länk för %2$s har löpt ut",
    "Shared by %2$s" : "Delad av %2$s",
    "Shares" : "Delningar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delat som länk",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
    "You can upload into this folder" : "Du kan ladda upp i denna map",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
    "Invalid server URL" : "Ogiltig server URL",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum satt",
    "Shared by" : "Delad av",
    "Sharing" : "Delning",
    "File shares" : "Fildelningar",
    "Downloaded via public link" : "Nedladdad via offentlig länk",
    "Downloaded by {email}" : "Nedladdad av {email}",
    "{file} downloaded via public link" : "{file} nedladdad via offentlig länk",
    "{email} downloaded {file}" : "{email} laddade ned {file}",
    "Shared with group {group}" : "Delad med grupp {group}",
    "Removed share for group {group}" : "Tog bort delning för grupp {group}",
    "{actor} shared with group {group}" : "{actor} delade med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} tog bort delningen för gruppen {group}",
    "You shared {file} with group {group}" : "Du delade {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du tog bort gruppen {group} från {file}",
    "{actor} shared {file} with group {group}" : "{actor} delade {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} tog bort gruppen {group} från {file}",
    "Shared as public link" : "Delades offentligt",
    "Removed public link" : "Tog bort offentlig länk",
    "Public link expired" : "Tidsgräns för offentlig länk har löpt ut",
    "{actor} shared as public link" : "{actor} delade offentligt",
    "{actor} removed public link" : "{actor} tog bort offentlig länk",
    "Public link of {actor} expired" : "Offentlig länk av {actor} har utgått",
    "You shared {file} as public link" : "Du delade {file} offentligt",
    "You removed public link for {file}" : "Du tog bort den offentliga länken för {file}",
    "Public link expired for {file}" : "Offentlig länk har utgått för {file}",
    "{actor} shared {file} as public link" : "{actor} delade {file} offentligt",
    "{actor} removed public link for {file}" : "{actor} tog bort den offentliga länken för {file}",
    "Public link of {actor} for {file} expired" : "Offentlig länk av {actor} för {file} har utgått",
    "{user} accepted the remote share" : "{user} accepterade extern delning",
    "{user} declined the remote share" : "{user} nekade extern delning",
    "You received a new remote share {file} from {user}" : "Du har fått en ny extern delning {file} från {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterade extern delning av {file}",
    "{user} declined the remote share of {file}" : "{user} nekade extern delning av {file}",
    "{user} unshared {file} from you" : "{user} slutade dela {file} med dig",
    "Shared with {user}" : "Delade med {user}",
    "Removed share for {user}" : "Tog bort delningen för {user}",
    "{actor} shared with {user}" : "{actor} delade med {user}",
    "{actor} removed share for {user}" : "{actor} tog bort delningen för {user}",
    "Shared by {actor}" : "Delad av {actor}",
    "{actor} removed share" : "{actor} tog bort delning",
    "You shared {file} with {user}" : "Du delade {file} med {user}",
    "You removed {user} from {file}" : "Du tog bort {user} från {file}",
    "{actor} shared {file} with {user}" : "{actor} delade {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
    "{actor} shared {file} with you" : "{actor} delade {file} med dig",
    "{actor} removed you from {file}" : "{actor} tog bort dig från {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via mejl eller offentlig länk har blivit <strong>nedladdad</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "Wrong share ID, share doesn't exist" : "Fel delnings-ID, delningen finns inte",
    "could not delete share" : "kunde inte ta bort delningen",
    "Could not delete share" : "Kunde inte ta bort delningen",
    "Please specify a file or folder path" : "Ange sökväg till filen eller mappen",
    "Wrong path, file/folder doesn't exist" : "Fel sökväg, fil/mapp finns inte",
    "Could not create share" : "Kunde inte skapa delning",
    "invalid permissions" : "ogiltiga behörigheter",
    "Please specify a valid user" : "Ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är avstängt",
    "Please specify a valid group" : "Ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Offentlig delningslänk är avstängt",
    "Public upload disabled by the administrator" : "Offentlig uppladdning är avstängt",
    "Public upload is only possible for publicly shared folders" : "Offentlig uppladdning fungerar endast i offentligt delade mappar",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delningen av %s misslyckades. Ej tillåtet med delning av %s",
    "You cannot share to a Circle if the app is not enabled" : "Du kan inte dela till en cirkel om appen inte är aktiverad",
    "Please specify a valid circle" : "Vänligen ange en giltig cirkel",
    "Unknown share type" : "Ogiltig delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökvägen",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Can't change permissions for public share links" : "Det går inte att ändra behörigheterna för offentliga länkar",
    "Cannot increase permissions" : "Kan inte utöka behörigheter",
    "%s is publicly shared" : "%s är offentligt delad",
    "Share API is disabled" : "Delning av API är inaktiverad",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Add to your Nextcloud" : "Lägg till i molnet",
    "Download" : "Ladda ned",
    "Download %s" : "Ladda ned %s",
    "Direct link" : "Direktlänk",
    "Upload files to %s" : "Ladda upp filer till %s",
    "Select or drop files" : "Välj eller dra filer hit",
    "Uploading files…" : "Laddar upp filer...",
    "Uploaded files:" : "Uppladdade filer:"
},
"nplurals=2; plural=(n != 1);");
